@@ -1,29 +1,36 @@
 /*
-  $Id: cdtext.c,v 1.2 2005/01/04 04:40:22 rocky Exp $
+  $Id: cdtext.c,v 1.5 2008/03/24 15:30:55 karl Exp $
 
-  Copyright (C) 2004, 2005 Rocky Bernstein <rocky@panix.com>
+  Copyright (C) 2004, 2005, 2006, 2008 Rocky Bernstein <rocky@gnu.org>
   
-  This program is free software; you can redistribute it and/or modify
+  This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
+  the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
-  
+
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-/* Simple program to list CD-Text info of  a Compact Disc using libcdio. */
+/* Simple program to list CD-Text info of a Compact Disc using
+   libcdio.  See also corresponding C++ programs of similar names. */
+
 #ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
+
+#ifdef HAVE_STDIO_H
 #include <stdio.h>
+#endif
+
+#ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
+#endif
 #include <cdio/cdio.h>
 #include <cdio/cdtext.h>
 
@@ -55,7 +62,7 @@ print_disc_info(CdIo_t *p_cdio, track_t i_tracks, track_t i_first_track) {
   print_cdtext_track_info(p_cdio, 0, "\nCD-Text for Disc:");
   for ( ; i_first_track < i_last_track; i_first_track++ ) {
     char psz_msg[50];
-    sprintf(psz_msg, "CD-Text for Track %d:", i_first_track);
+    snprintf(psz_msg, sizeof(psz_msg), "CD-Text for Track %d:", i_first_track);
     print_cdtext_track_info(p_cdio, i_first_track, psz_msg);
   }
 }
@@ -77,7 +84,7 @@ main(int argc, const char *argv[])
     cdio_destroy(p_cdio);
   }
 
-  p_cdio = cdio_open (NULL, DRIVER_UNKNOWN);
+  p_cdio = cdio_open (NULL, DRIVER_DEVICE);
   i_first_track = cdio_get_first_track_num(p_cdio);
   i_tracks      = cdio_get_num_tracks(p_cdio);
 
