@@ -1,17 +1,17 @@
 /*
-    $Id: iso9660.h,v 1.96 2007/08/11 16:26:14 rocky Exp $
+    $Id: iso9660.h,v 1.102 2008/07/16 00:28:54 rocky Exp $
 
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008
+                  Rocky Bernstein <rocky@gnu.org>
     Copyright (C) 2000 Herbert Valerio Riedel <hvr@gnu.org>
-    Copyright (C) 2003, 2004, 2005, 2006, 2007 Rocky Bernstein <rocky@gnu.org>
 
     See also iso9660.h by Eric Youngdale (1993).
 
     Copyright 1993 Yggdrasil Computing, Incorporated
-    Copyright (c) 1999,2000 J. Schilling
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -20,9 +20,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301 USA.
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 /*!
  * \file iso9660.h 
@@ -69,7 +67,11 @@ typedef char     dchar_t;  /*! See section 7.4.1 */
 #include <cdio/types.h>
 #include <cdio/xa.h>
 
-#define	_delta(from, to)	((to) - (from) + 1)
+#ifdef ISODCL
+#undef ISODCL
+#endif
+/* This part borrowed from the bsd386 isofs */
+#define	ISODCL(from, to)	((to) - (from) + 1)
 
 #define MIN_TRACK_SIZE 4*75
 #define MIN_ISO_SIZE MIN_TRACK_SIZE
@@ -203,18 +205,18 @@ typedef struct iso9660_dtime_s  iso9660_dtime_t;
   @see iso9660_ltime
  */
 struct	iso9660_ltime_s {
-  char	 lt_year	[_delta(   1,	4)];   /**< Add 1900 to value
+  char	 lt_year	[ISODCL(   1,	4)];   /**< Add 1900 to value
                                                     for the Julian
                                                     year */
-  char	 lt_month	[_delta(   5,	6)];   /**< Has value in range
+  char	 lt_month	[ISODCL(   5,	6)];   /**< Has value in range
                                                   1..12. Note starts
                                                   at 1, not 0 like a
                                                   tm struct. */
-  char	 lt_day		[_delta(   7,	8)];   /**< Day of month: 1..31 */
-  char	 lt_hour	[_delta(   9,	10)];  /**< hour: 0..23 */
-  char	 lt_minute	[_delta(  11,	12)];  /**< minute: 0..59 */
-  char	 lt_second	[_delta(  13,	14)];  /**< second: 0..59 */
-  char	 lt_hsecond	[_delta(  15,	16)];  /**< The value is in
+  char	 lt_day		[ISODCL(   7,	8)];   /**< Day of month: 1..31 */
+  char	 lt_hour	[ISODCL(   9,	10)];  /**< hour: 0..23 */
+  char	 lt_minute	[ISODCL(  11,	12)];  /**< minute: 0..59 */
+  char	 lt_second	[ISODCL(  13,	14)];  /**< second: 0..59 */
+  char	 lt_hsecond	[ISODCL(  15,	16)];  /**< The value is in
                                                   units of 1/100's of
                                                   a second */
   iso712_t lt_gmtoff;  /**< Offset from Greenwich Mean Time in number
@@ -685,10 +687,10 @@ typedef struct _iso9660_s iso9660_t;
     record. Even though tm_wday and tm_yday fields are not explicitly in
     idr_date, they are calculated from the other fields.
     
-    If tm is to reflect the localtime, set "use_localtime" true, otherwise
+    If tm is to reflect the localtime, set "b_localtime" true, otherwise
     tm will reported in GMT.
   */
-  bool iso9660_get_dtime (const iso9660_dtime_t *idr_date, bool use_localtime,
+  bool iso9660_get_dtime (const iso9660_dtime_t *idr_date, bool b_localtime,
                           /*out*/ struct tm *tm);
   
   
@@ -963,7 +965,8 @@ lsn_t iso9660_get_dir_extent(const iso9660_dir_t *p_idr);
   /*!
     Return the directory name stored in the iso9660_dir_t
     
-    A string is allocated: the caller must deallocate.
+    A string is allocated: the caller must deallocate. This routine
+    can return NULL if memory allocation fails.
   */
   char * iso9660_dir_to_name (const iso9660_dir_t *p_iso9660_dir);
   
@@ -1099,6 +1102,7 @@ lsn_t iso9660_get_dir_extent(const iso9660_dir_t *p_idr);
 }
 #endif /* __cplusplus */
 
+#undef ISODCL
 #endif /* __CDIO_ISO9660_H__ */
 
 /* 
