@@ -1,22 +1,21 @@
 /*
-  $Id: paranoia.h,v 1.13 2006/10/27 10:38:41 rocky Exp $
+    $Id: paranoia.h,v 1.15 2008/03/25 15:59:09 karl Exp $
 
-  Copyright (C) 2004, 2005, 2006 Rocky Bernstein <rocky@panix.com>
-  Copyright (C) 1998 Monty xiphmont@mit.edu
+    Copyright (C) 2004, 2005, 2006, 2007, 2008 Rocky Bernstein <rocky@gnu.org>
+    Copyright (C) 1998 Monty xiphmont@mit.edu
   
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-  
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-  
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    This program is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /** \file paranoia.h 
@@ -183,7 +182,7 @@ extern "C" {
 #define paranoia_read         cdio_paranoia_read
 #define paranoia_read_limited cdio_paranoia_read_limited
 #define paranoia_overlapset   cdio_paranoia_overlapset
-#define paranoia_set_range    cdio_paranoia_read_overlapset
+#define paranoia_set_range    cdio_paranoia_set_range
 #endif /*DO_NOT_WANT_PARANOIA_COMPATIBILITY*/
 
 #ifdef __cplusplus
