@@ -1,12 +1,12 @@
 /*
-    $Id: sector.h,v 1.36 2005/03/06 11:21:52 rocky Exp $
+    $Id: sector.h,v 1.38 2008/03/25 15:59:09 karl Exp $
 
+    Copyright (C) 2003, 2004, 2005, 2006, 2008 Rocky Bernstein <rocky@gnu.org>
     Copyright (C) 2000 Herbert Valerio Riedel <hvr@gnu.org>
-    Copyright (C) 2003, 2004, 2005 Rocky Bernstein <rocky@panix.com>
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 /*!
    \file sector.h 
@@ -90,7 +89,7 @@
 #define CDIO_PREGAP_SECTORS  150
 #define CDIO_POSTGAP_SECTORS 150
       
-      /*! An enumeration for some of the CDIO_CD #defines below. This isn't
+      /*! An enumeration for some of the CDIO_CD \#defines below. This isn't
         really an enumeration one would really use in a program it is to
         be helpful in debuggers where wants just to refer to the CDIO_CD_
         names and get something.
@@ -171,7 +170,7 @@
         {0, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0};
       */
       
-      /*! An enumeration for some of the M2*_SECTOR_SIZE #defines
+      /*! An enumeration for some of the M2*_SECTOR_SIZE \#defines
         below. This isn't really an enumeration one would really use in a
         program it is to be helpful in debuggers where wants just to refer
         to the M2*_SECTOR_SIZE names and get something.
