@@ -1,12 +1,12 @@
 /*
-    $Id: util.h,v 1.10 2006/03/18 00:53:20 rocky Exp $
+    $Id: util.h,v 1.12 2008/03/25 15:59:10 karl Exp $
 
+    Copyright (C) 2004, 2005, 2006, 2008 Rocky Bernstein <rocky@gnu.org>
     Copyright (C) 2000 Herbert Valerio Riedel <hvr@gnu.org>
-    Copyright (C) 2004, 2005, 2006 Rocky Bernstein <rocky@panix.com>
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef __CDIO_UTIL_H__
@@ -100,6 +99,8 @@ _cdio_strsplit(const char str[], char delim);
 uint8_t cdio_to_bcd8(uint8_t n);
 uint8_t cdio_from_bcd8(uint8_t p);
 
+void cdio_follow_symlink (const char * src, char * dst);
+  
 #ifdef __cplusplus
 }
 #endif
