@@ -1,21 +1,20 @@
 /*
-    $Id: aspi32.c,v 1.9 2005/08/28 22:40:19 rocky Exp $
+  $Id: aspi32.c,v 1.11 2008/04/21 18:30:21 karl Exp $
 
-    Copyright (C) 2004, 2005 Rocky Bernstein <rocky@panix.com>
+  Copyright (C) 2004, 2005, 2008 Rocky Bernstein <rocky@gnu.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /* This file contains Win32-specific code and implements low-level 
@@ -27,7 +26,7 @@
 # include "config.h"
 #endif
 
-static const char _rcsid[] = "$Id: aspi32.c,v 1.9 2005/08/28 22:40:19 rocky Exp $";
+static const char _rcsid[] = "$Id: aspi32.c,v 1.11 2008/04/21 18:30:21 karl Exp $";
 
 #include <cdio/cdio.h>
 #include <cdio/sector.h>
@@ -489,7 +488,7 @@ init_aspi (_img_private_t *env)
 int
 run_mmc_cmd_aspi( void *p_user_data, unsigned int i_timeout_ms,
 		  unsigned int i_cdb, const mmc_cdb_t * p_cdb,  
-		  mmc_direction_t e_direction, 
+		  cdio_mmc_direction_t e_direction, 
 		  unsigned int i_buf, /*in/out*/ void *p_buf )
 {
   const _img_private_t *p_env = p_user_data;
