@@ -1,32 +1,30 @@
 /*
-    $Id: _cdio_generic.c,v 1.22 2006/03/26 02:35:26 rocky Exp $
+  $Id: _cdio_generic.c,v 1.27 2008/04/22 15:29:11 karl Exp $
 
-    Copyright (C) 2004, 2005, 2006
-    Rocky Bernstein <rockyb@users.sourceforge.net>
+  Copyright (C) 2004, 2005, 2006, 2007, 2008 Rocky Bernstein <rocky@gnu.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-/* This file contains generic implementations of device-dirver routines.
+/* This file contains generic implementations of device-driver routines.
 */
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
 
-static const char _rcsid[] = "$Id: _cdio_generic.c,v 1.22 2006/03/26 02:35:26 rocky Exp $";
+static const char _rcsid[] = "$Id: _cdio_generic.c,v 1.27 2008/04/22 15:29:11 karl Exp $";
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -38,6 +36,7 @@ static const char _rcsid[] = "$Id: _cdio_generic.c,v 1.22 2006/03/26 02:35:26 ro
 #endif /*HAVE_UNISTD_H*/
 
 #include <fcntl.h>
+#include <limits.h>
 
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -92,8 +91,10 @@ cdio_generic_free (void *p_user_data)
   if (NULL == p_env) return;
   if (p_env->source_name) free (p_env->source_name);
 
-  for (i_track=0; i_track < p_env->i_tracks; i_track++) {
-    cdtext_destroy(&(p_env->cdtext_track[i_track]));
+  if (p_env->b_cdtext_init) {
+    for (i_track=0; i_track < p_env->i_tracks; i_track++) {
+      cdtext_destroy(&(p_env->cdtext_track[i_track]));
+    }
   }
 
   if (p_env->fd >= 0)
@@ -221,24 +222,22 @@ cdio_add_device_list(char **device_list[], const char *drive,
 {
   if (NULL != drive) {
     unsigned int j;
-
+    char real_device_1[PATH_MAX];
+    char real_device_2[PATH_MAX];
+    cdio_follow_symlink(drive, real_device_1);
     /* Check if drive is already in list. */
     for (j=0; j<*num_drives; j++) {
-      if (strcmp((*device_list)[j], drive) == 0) break;
+      cdio_follow_symlink((*device_list)[j], real_device_2);
+      if (strcmp(real_device_1, real_device_2) == 0) break;
     }
 
     if (j==*num_drives) {
       /* Drive not in list. Add it. */
       (*num_drives)++;
-      if (*device_list) {
-        *device_list = realloc(*device_list, (*num_drives) * sizeof(char *));
-      } else {
-        /* num_drives should be 0. Add assert? */
-        *device_list = malloc((*num_drives) * sizeof(char *));
+      *device_list = realloc(*device_list, (*num_drives) * sizeof(char *));
+      (*device_list)[*num_drives-1] = strdup(drive);
       }
       
-      (*device_list)[*num_drives-1] = strdup(drive);
-    }
   } else {
     (*num_drives)++;
     if (*device_list) {
