@@ -1,23 +1,22 @@
 /*
-    $Id: cdtext.c,v 1.4 2005/03/23 11:15:25 rocky Exp $
+  $Id: cdtext.c,v 1.7 2008/06/16 22:41:44 flameeyes Exp $
 
-    Copyright (C) 2004, 2005 Rocky Bernstein <rocky@panix.com>
-    toc reading routine adapted from cuetools
-    Copyright (C) 2003 Svend Sanjay Sorensen <ssorensen@fastmail.fm>
+  Copyright (C) 2004, 2005, 2008 Rocky Bernstein <rocky@gnu.org>
+  toc reading routine adapted from cuetools
+  Copyright (C) 2003 Svend Sanjay Sorensen <ssorensen@fastmail.fm>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifdef HAVE_CONFIG_H
@@ -38,7 +37,7 @@
 
 /*! Note: the order and number items (except CDTEXT_INVALID) should
   match the cdtext_field_t enumeration. */
-const char *cdtext_keywords[] = 
+static const char cdtext_keywords[][16] = 
   {
     "ARRANGER",
     "COMPOSER",
@@ -89,10 +88,18 @@ cdtext_destroy (cdtext_t *p_cdtext)
 char *
 cdtext_get (cdtext_field_t key, const cdtext_t *p_cdtext)
 {
-  if (key == CDTEXT_INVALID) return NULL;
+  if ((key == CDTEXT_INVALID) || (!p_cdtext->field[key])) return NULL;
   return strdup(p_cdtext->field[key]);
 }
 
+const char *
+cdtext_get_const (cdtext_field_t key, const cdtext_t *p_cdtext)
+{
+  if (key == CDTEXT_INVALID) return NULL;
+  return p_cdtext->field[key];
+}
+
+
 /*! Initialize a new cdtext structure.
   When the structure is no longer needed, release the 
   resources using cdtext_delete.
