@@ -1,21 +1,20 @@
 /*
-    $Id: device.c,v 1.39 2006/04/04 02:06:13 rocky Exp $
+  $Id: device.c,v 1.41 2008/04/22 15:29:12 karl Exp $
 
-    Copyright (C) 2005, 2006 Rocky Bernstein <rocky@panix.com>
+  Copyright (C) 2005, 2006, 2008 Rocky Bernstein <rocky@gnu.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 /*! device- and driver-related routines. */
 
@@ -149,6 +148,19 @@ CdIo_driver_t CdIo_all_drivers[CDIO_MAX_DRIVER+1] = {
    &close_tray_freebsd
   },
 
+  {DRIVER_NETBSD, 
+   CDIO_SRC_IS_DEVICE_MASK|CDIO_SRC_IS_NATIVE_MASK|CDIO_SRC_IS_SCSI_MASK,
+   "NetBSD",
+   "NetBSD driver",
+   &cdio_have_netbsd,
+   &cdio_open_netbsd,
+   &cdio_open_am_netbsd,
+   &cdio_get_default_device_netbsd,
+   &cdio_is_device_generic,
+   &cdio_get_devices_netbsd,
+   &close_tray_netbsd
+  },
+
   {DRIVER_LINUX, 
    CDIO_SRC_IS_DEVICE_MASK|CDIO_SRC_IS_NATIVE_MASK,
    "GNU/Linux", 
@@ -923,6 +935,7 @@ cdio_open_am (const char *psz_orig_source, driver_id_t driver_id,
   case DRIVER_BSDI:
   case DRIVER_FREEBSD:
   case DRIVER_LINUX:
+  case DRIVER_NETBSD:
   case DRIVER_SOLARIS:
   case DRIVER_WIN32:
   case DRIVER_OSX:
