@@ -1,23 +1,22 @@
 /*
-    $Id: gnu_linux.c,v 1.26 2006/10/21 11:38:16 rocky Exp $
+  $Id: gnu_linux.c,v 1.33 2008/06/25 07:46:21 rocky Exp $
 
-    Copyright (C) 2001 Herbert Valerio Riedel <hvr@gnu.org>
-    Copyright (C) 2002, 2003, 2004, 2005, 2006 Rocky Bernstein 
-    <rockyb@users.sourceforge.net>
+  Copyright (C) 2001 Herbert Valerio Riedel <hvr@gnu.org>
+  Copyright (C) 2002, 2003, 2004, 2005, 2006, 2008 
+    Rocky Bernstein <rocky@gnu.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /* This file contains Linux-specific code and implements low-level 
@@ -28,12 +27,11 @@
 # include "config.h"
 #endif
 
-static const char _rcsid[] = "$Id: gnu_linux.c,v 1.26 2006/10/21 11:38:16 rocky Exp $";
+static const char _rcsid[] = "$Id: gnu_linux.c,v 1.33 2008/06/25 07:46:21 rocky Exp $";
 
+#ifdef HAVE_STRING_H
 #include <string.h>
-#include <limits.h>
-#include <sys/types.h>
-#include <sys/wait.h>
+#endif
 
 #include <cdio/sector.h>
 #include <cdio/util.h>
@@ -47,6 +45,10 @@ static const char _rcsid[] = "$Id: gnu_linux.c,v 1.26 2006/10/21 11:38:16 rocky
 
 #ifdef HAVE_LINUX_CDROM
 
+#include <sys/types.h>
+#include <sys/wait.h>
+#include <limits.h>
+
 #if defined(HAVE_LINUX_VERSION_H)
 # include <linux/version.h>
 # if LINUX_VERSION_CODE >= KERNEL_VERSION(2,2,16)
@@ -595,30 +597,6 @@ get_track_msf_linux(void *p_user_data, track_t i_track, msf_t *msf)
   }
 }
 
-/*!
-  Follow symlinks until we have the real device file
-  (idea taken from libunieject). 
-*/
-
-static void follow_symlink (const char * src, char * dst) {
-  char tmp_src[PATH_MAX];
-  char tmp_dst[PATH_MAX];
-  
-  int len;
-
-  strcpy(tmp_src, src);
-  while(1) {
-    len = readlink(tmp_src, tmp_dst, PATH_MAX);
-    if(len < 0) {
-      strcpy(dst, tmp_src);
-      return;
-    }
-    else {
-      tmp_dst[len] = '\0';
-      strcpy(tmp_src, tmp_dst);
-    }
-  }
-}
 
 /*!
   Check, if a device is mounted and return the target (=mountpoint)
@@ -642,12 +620,12 @@ static int is_mounted (const char * device, char * target) {
   if(!fp) return 0;
 
   /* Get real device */
-  follow_symlink(device, real_device_1);
+  cdio_follow_symlink(device, real_device_1);
     
   /* Read entries */
 
   while ( fscanf(fp, "%s %s %*s %*s %*d %*d\n", file_device, file_target) != EOF ) {
-    follow_symlink(file_device, real_device_2);
+    cdio_follow_symlink(file_device, real_device_2);
     if(!strcmp(real_device_1, real_device_2)) {
       strcpy(target, file_target);
       fclose(fp);
@@ -1348,12 +1326,25 @@ set_arg_linux (void *p_user_data, const char key[], const char value[])
 }
 
 /* checklist: /dev/cdrom, /dev/dvd /dev/hd?, /dev/scd? /dev/sr? */
-static char checklist1[][40] = {
-  {"cdrom"}, {"dvd"}, {""}
-};
-static char checklist2[][40] = {
-  {"?a hd?"}, {"?0 scd?"}, {"?0 sr?"}, {""}
+static const char checklist1[][40] = {
+  {"cdrom"}, {"dvd"}
 };
+static const int checklist1_size = sizeof(checklist1) / sizeof(checklist1[0]);
+
+static const struct
+  {
+    char format[22];
+    int num_min;
+    int num_max;
+  }
+checklist2[] =
+  {
+    { "/dev/hd%c",  'a', 'z' },
+    { "/dev/scd%d", 0,   27 },
+    { "/dev/sr%d",  0,   27 },
+  };
+static const int checklist2_size = sizeof(checklist2) / sizeof(checklist2[0]);
+
 
 /* Set CD-ROM drive speed */
 static driver_return_code_t
@@ -1379,15 +1370,15 @@ cdio_get_devices_linux (void)
   unsigned int i;
   char drive[40];
   char *ret_drive;
-  bool exists;
   char **drives = NULL;
   unsigned int num_drives=0;
-  
+
   /* Scan the system for CD-ROM drives.
   */
-  for ( i=0; strlen(checklist1[i]) > 0; ++i ) {
-    sprintf(drive, "/dev/%s", checklist1[i]);
-    if ( (exists=is_cdrom_linux(drive, NULL)) > 0 ) {
+  for ( i=0; i < checklist1_size; ++i ) {
+    if (snprintf(drive, sizeof(drive), "/dev/%s", checklist1[i]) < 0)
+      continue;
+    if ( is_cdrom_linux(drive, NULL) > 0 ) {
       cdio_add_device_list(&drives, drive, &num_drives);
     }
   }
@@ -1407,17 +1398,12 @@ cdio_get_devices_linux (void)
   /* Scan the system for CD-ROM drives.
      Not always 100% reliable, so use the USE_MNTENT code above first.
   */
-  for ( i=0; strlen(checklist2[i]) > 0; ++i ) {
+  for ( i=0; i < checklist2_size; ++i ) {
     unsigned int j;
-    char *insert;
-    exists = true;
-    for ( j=checklist2[i][1]; exists; ++j ) {
-      sprintf(drive, "/dev/%s", &checklist2[i][3]);
-      insert = strchr(drive, '?');
-      if ( insert != NULL ) {
-	*insert = j;
-      }
-      if ( (exists=is_cdrom_linux(drive, NULL)) > 0 ) {
+    for ( j=checklist2[i].num_min; j<=checklist2[i].num_max; ++j ) {
+      if (snprintf(drive, sizeof(drive), checklist2[i].format, j) < 0)
+        continue;
+      if ( (is_cdrom_linux(drive, NULL)) > 0 ) {
 	cdio_add_device_list(&drives, drive, &num_drives);
       }
     }
@@ -1439,14 +1425,14 @@ cdio_get_default_device_linux(void)
 #else
   unsigned int i;
   char drive[40];
-  bool exists;
   char *ret_drive;
 
   /* Scan the system for CD-ROM drives.
   */
   for ( i=0; strlen(checklist1[i]) > 0; ++i ) {
-    sprintf(drive, "/dev/%s", checklist1[i]);
-    if ( (exists=is_cdrom_linux(drive, NULL)) > 0 ) {
+    if (snprintf(drive, sizeof(drive), "/dev/%s", checklist1[i]) < 0)
+      continue;
+    if ( is_cdrom_linux(drive, NULL) > 0 ) {
       return strdup(drive);
     }
   }
@@ -1462,17 +1448,12 @@ cdio_get_default_device_linux(void)
   /* Scan the system for CD-ROM drives.
      Not always 100% reliable, so use the USE_MNTENT code above first.
   */
-  for ( i=0; strlen(checklist2[i]) > 0; ++i ) {
+  for ( i=0; checklist2[i].format; ++i ) {
     unsigned int j;
-    char *insert;
-    exists = true;
-    for ( j=checklist2[i][1]; exists; ++j ) {
-      sprintf(drive, "/dev/%s", &checklist2[i][3]);
-      insert = strchr(drive, '?');
-      if ( insert != NULL ) {
-	*insert = j;
-      }
-      if ( (exists=is_cdrom_linux(drive, NULL)) > 0 ) {
+    for ( j=checklist2[i].num_min; j<=checklist2[i].num_max; ++j ) {
+      if (snprintf(drive, sizeof(drive), checklist2[i].format, j) < 0)
+        continue;
+      if ( is_cdrom_linux(drive, NULL) > 0 ) {
 	return(strdup(drive));
       }
     }
@@ -1660,6 +1641,7 @@ cdio_open_am_linux (const char *psz_orig_source, const char *access_mode)
     return ret;
   } else {
     cdio_generic_free (_data);
+    free(ret);
     return NULL;
   }
   
