@@ -1,25 +1,24 @@
 /*
-    $Id: bincue.c,v 1.19 2006/02/13 11:00:53 rocky Exp $
+  $Id: bincue.c,v 1.23 2008/04/21 18:30:22 karl Exp $
 
-    Copyright (C) 2002, 2003, 2004, 2005, 2006 
-    Rocky Bernstein <rocky@panix.com>
-    Copyright (C) 2001 Herbert Valerio Riedel <hvr@gnu.org>
+  Copyright (C) 2002, 2003, 2004, 2005, 2006, 2008
+    Rocky Bernstein <rocky@gnu.org>
+  Copyright (C) 2001 Herbert Valerio Riedel <hvr@gnu.org>
     cue parsing routine adapted from cuetools
-    Copyright (C) 2003 Svend Sanjay Sorensen <ssorensen@fastmail.fm>
+  Copyright (C) 2003 Svend Sanjay Sorensen <ssorensen@fastmail.fm>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /* This code implements low-level access functions for a CD images
@@ -27,7 +26,7 @@
    (*.cue).
 */
 
-static const char _rcsid[] = "$Id: bincue.c,v 1.19 2006/02/13 11:00:53 rocky Exp $";
+static const char _rcsid[] = "$Id: bincue.c,v 1.23 2008/04/21 18:30:22 karl Exp $";
 
 #include "image.h"
 #include "cdio_assert.h"
@@ -632,7 +631,7 @@ parse_cuefile (_img_private_t *cd, const char *psz_cue_name)
 	      goto err_exit;
 	    }
 	    if (cd) {
-	      cd->tocent[i].pregap = lba;
+	      cd->tocent[i].silence = lba;
 	    }
 	  } else {
 	    goto format_error;
@@ -672,7 +671,14 @@ parse_cuefile (_img_private_t *cd, const char *psz_cue_name)
 	      track_info_t  *this_track=
 		&(cd->tocent[cd->gen.i_tracks - cd->gen.i_first_track]);
 
-	      if (start_index != 0) {
+	      switch (start_index) {
+
+	      case 0:
+		lba += CDIO_PREGAP_SECTORS;
+		this_track->pregap = lba;
+		break;
+
+	      case 1:
 		if (!b_first_index_for_track) {
 		  lba += CDIO_PREGAP_SECTORS;
 		  cdio_lba_to_msf(lba, &(this_track->start_msf));
@@ -709,6 +715,10 @@ parse_cuefile (_img_private_t *cd, const char *psz_cue_name)
 		  }
 		}
 		this_track->num_indices++;
+		break;
+
+	      default:
+		break;
 	      }
 	    }
 #endif  
@@ -782,25 +792,12 @@ _read_audio_sectors_bincue (void *p_user_data, void *data, lsn_t lsn,
   _img_private_t *p_env = p_user_data;
   int ret;
 
-  /* Why the adjustment of 272, I don't know. It seems to work though */
-  if (lsn != 0) {
-    ret = cdio_stream_seek (p_env->gen.data_source, 
-			    (lsn * CDIO_CD_FRAMESIZE_RAW) - 272, SEEK_SET);
-    if (ret!=0) return ret;
+  ret = cdio_stream_seek (p_env->gen.data_source, 
+            lsn * CDIO_CD_FRAMESIZE_RAW, SEEK_SET);
+  if (ret!=0) return ret;
 
-    ret = cdio_stream_read (p_env->gen.data_source, data, 
-			    CDIO_CD_FRAMESIZE_RAW, nblocks);
-  } else {
-    /* We need to pad out the first 272 bytes with 0's */
-    BZERO(data, 272);
-    
-    ret = cdio_stream_seek (p_env->gen.data_source, 0, SEEK_SET);
-
-    if (ret!=0) return ret;
-
-    ret = cdio_stream_read (p_env->gen.data_source, (uint8_t *) data+272, 
-			    CDIO_CD_FRAMESIZE_RAW - 272, nblocks);
-  }
+  ret = cdio_stream_read (p_env->gen.data_source, data, 
+            CDIO_CD_FRAMESIZE_RAW, nblocks);
 
   /* ret is number of bytes if okay, but we need to return 0 okay. */
   return ret == 0;
@@ -1156,13 +1153,15 @@ cdio_open_cue (const char *psz_cue_name)
   _funcs.get_media_changed     = get_media_changed_image;
   _funcs.get_mcn               = _get_mcn_image;
   _funcs.get_num_tracks        = _get_num_tracks_image;
-  _funcs.get_track_channels    = get_track_channels_image,
-  _funcs.get_track_copy_permit = get_track_copy_permit_image,
+  _funcs.get_track_channels    = get_track_channels_image;
+  _funcs.get_track_copy_permit = get_track_copy_permit_image;
   _funcs.get_track_format      = _get_track_format_bincue;
   _funcs.get_track_green       = _get_track_green_bincue;
   _funcs.get_track_lba         = _get_lba_track_bincue;
   _funcs.get_track_msf         = _get_track_msf_image;
-  _funcs.get_track_preemphasis = get_track_preemphasis_image,
+  _funcs.get_track_preemphasis = get_track_preemphasis_image;
+  _funcs.get_track_pregap_lba  = get_track_pregap_lba_image;
+  _funcs.get_track_isrc        = get_track_isrc_image;
   _funcs.lseek                 = _lseek_bincue;
   _funcs.read                  = _read_bincue;
   _funcs.read_audio_sectors    = _read_audio_sectors_bincue;
