@@ -1,23 +1,22 @@
 /*
-    $Id: cdrdao.c,v 1.23 2007/03/05 11:49:24 rocky Exp $
+  $Id: cdrdao.c,v 1.27 2008/04/21 18:30:22 karl Exp $
 
-    Copyright (C) 2004, 2005, 2006, 2007 Rocky Bernstein <rocky@gnu.org>
+  Copyright (C) 2004, 2005, 2006, 2007, 2008 Rocky Bernstein <rocky@gnu.org>
     toc reading routine adapted from cuetools
-    Copyright (C) 2003 Svend Sanjay Sorensen <ssorensen@fastmail.fm>
+  Copyright (C) 2003 Svend Sanjay Sorensen <ssorensen@fastmail.fm>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /* This code implements low-level access functions for a CD images
@@ -25,7 +24,7 @@
    (*.cue).
 */
 
-static const char _rcsid[] = "$Id: cdrdao.c,v 1.23 2007/03/05 11:49:24 rocky Exp $";
+static const char _rcsid[] = "$Id: cdrdao.c,v 1.27 2008/04/21 18:30:22 karl Exp $";
 
 #include "image.h"
 #include "cdio_assert.h"
@@ -825,6 +824,7 @@ parse_tocfile (_img_private_t *cd, const char *psz_cue_name)
 	  if (NULL != (psz_field = strtok (NULL, " \t\n\r"))) {
 	    /* todo: line is too long! */
 	    if (NULL != cd) {
+	      cd->tocent[i].pregap = cd->tocent[i].start_lba;
 	      cd->tocent[i].start_lba += cdio_mmssff_to_lba (psz_field);
 	      cdio_lba_to_msf(cd->tocent[i].start_lba, 
 			      &(cd->tocent[i].start_msf));
@@ -843,7 +843,7 @@ parse_tocfile (_img_private_t *cd, const char *psz_cue_name)
 	if (0 <= i) {
 	  if (NULL != (psz_field = strtok (NULL, " \t\n\r"))) {
 	    if (NULL != cd) 
-	      cd->tocent[i].pregap = cdio_mmssff_to_lba (psz_field);
+	      cd->tocent[i].silence = cdio_mmssff_to_lba (psz_field);
 	  } else {
 	    goto format_error;
 	  }
@@ -974,25 +974,12 @@ _read_audio_sectors_cdrdao (void *user_data, void *data, lsn_t lsn,
   _img_private_t *env = user_data;
   int ret;
 
-  /* Why the adjustment of 272, I don't know. It seems to work though */
-  if (lsn != 0) {
-    ret = cdio_stream_seek (env->tocent[0].data_source, 
-			    (lsn * CDIO_CD_FRAMESIZE_RAW) - 272, SEEK_SET);
-    if (ret!=0) return ret;
+  ret = cdio_stream_seek (env->tocent[0].data_source, 
+            lsn * CDIO_CD_FRAMESIZE_RAW, SEEK_SET);
+  if (ret!=0) return ret;
 
-    ret = cdio_stream_read (env->tocent[0].data_source, data, 
-			    CDIO_CD_FRAMESIZE_RAW, nblocks);
-  } else {
-    /* We need to pad out the first 272 bytes with 0's */
-    BZERO(data, 272);
-    
-    ret = cdio_stream_seek (env->tocent[0].data_source, 0, SEEK_SET);
-
-    if (ret!=0) return ret;
-
-    ret = cdio_stream_read (env->tocent[0].data_source, (uint8_t *) data+272, 
-			    CDIO_CD_FRAMESIZE_RAW - 272, nblocks);
-  }
+  ret = cdio_stream_read (env->tocent[0].data_source, data, 
+            CDIO_CD_FRAMESIZE_RAW, nblocks);
 
   /* ret is number of bytes if okay, but we need to return 0 okay. */
   return ret == 0;
@@ -1288,13 +1275,15 @@ cdio_open_cdrdao (const char *psz_cue_name)
   _funcs.get_media_changed     = get_media_changed_image;
   _funcs.get_mcn               = _get_mcn_image;
   _funcs.get_num_tracks        = _get_num_tracks_image;
-  _funcs.get_track_channels    = get_track_channels_image,
-  _funcs.get_track_copy_permit = get_track_copy_permit_image,
+  _funcs.get_track_channels    = get_track_channels_image;
+  _funcs.get_track_copy_permit = get_track_copy_permit_image;
   _funcs.get_track_format      = _get_track_format_cdrdao;
   _funcs.get_track_green       = _get_track_green_cdrdao;
   _funcs.get_track_lba         = _get_lba_track_cdrdao;
   _funcs.get_track_msf         = _get_track_msf_image;
-  _funcs.get_track_preemphasis = get_track_preemphasis_image,
+  _funcs.get_track_preemphasis = get_track_preemphasis_image;
+  _funcs.get_track_pregap_lba  = get_track_pregap_lba_image;
+  _funcs.get_track_isrc        = get_track_isrc_image;
   _funcs.lseek                 = _lseek_cdrdao;
   _funcs.read                  = _read_cdrdao;
   _funcs.read_audio_sectors    = _read_audio_sectors_cdrdao;
