@@ -1,22 +1,21 @@
 /*
-    $Id: nrg.c,v 1.18 2005/07/07 06:51:58 rocky Exp $
+  $Id: nrg.c,v 1.31 2008/04/21 18:30:22 karl Exp $
 
-    Copyright (C) 2003, 2004, 2005 Rocky Bernstein <rocky@panix.com>
-    Copyright (C) 2001, 2003 Herbert Valerio Riedel <hvr@gnu.org>
+  Copyright (C) 2003, 2004, 2005, 2006, 2008 Rocky Bernstein <rocky@panix.com>
+  Copyright (C) 2001, 2003 Herbert Valerio Riedel <hvr@gnu.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 /*! This code implements low-level access functions for the Nero native
    CD-image format residing inside a disk file (*.nrg).
@@ -46,11 +45,12 @@
 #include "_cdio_stdio.h"
 #include "nrg.h"
 
-static const char _rcsid[] = "$Id: nrg.c,v 1.18 2005/07/07 06:51:58 rocky Exp $";
+static const char _rcsid[] = "$Id: nrg.c,v 1.31 2008/04/21 18:30:22 karl Exp $";
 
+nero_id_t    nero_id;
+nero_dtype_t nero_dtype;
 
 /* reader */
-
 #define DEFAULT_CDIO_DEVICE "image.nrg"
 
 /* 
@@ -68,7 +68,8 @@ typedef struct {
 #define NEED_NERO_STRUCT
 #include "image_common.h"
 
-static bool  parse_nrg (_img_private_t *env, const char *psz_cue_name);
+static bool  parse_nrg (_img_private_t *env, const char *psz_cue_name,
+			const cdio_log_level_t log_level);
 static lsn_t get_disc_last_lsn_nrg (void *p_user_data);
 
 /* Updates internal track TOC, so we can later 
@@ -174,13 +175,12 @@ _register_mapping (_img_private_t *env, lsn_t start_lsn, uint32_t sec_count,
    FIXME: right now psz_nrg_name is not used. It will be in the future.
  */
 static bool
-parse_nrg (_img_private_t *p_env, const char *psz_nrg_name)
+parse_nrg (_img_private_t *p_env, const char *psz_nrg_name, 
+	   const cdio_log_level_t log_level)
 {
   long unsigned int footer_start;
   long unsigned int size;
   char *footer_buf = NULL;
-  cdio_log_level_t log_level = (NULL == p_env) ? CDIO_LOG_INFO : CDIO_LOG_WARN;
-
   size = cdio_stream_stat (p_env->gen.data_source);
   if (-1 == size) return false;
 
@@ -206,7 +206,7 @@ parse_nrg (_img_private_t *p_env, const char *psz_nrg_name)
     cdio_debug (".NRG footer start = %ld, length = %ld", 
 	       (long) footer_start, (long) (size - footer_start));
 
-    cdio_assert (IN ((size - footer_start), 0, 4096));
+    cdio_assert ((size - footer_start) <= 4096);
 
     footer_buf = calloc(1, size - footer_start);
 
@@ -298,12 +298,14 @@ parse_nrg (_img_private_t *p_env, const char *psz_nrg_name)
 #else
 		  lsn = CDIO_INVALID_LSN;
 #endif		  
-		  cdio_warn ("untested (i.e. probably wrong) CUE MSF code");
+		  cdio_log (log_level, 
+			    "untested (i.e. probably wrong) CUE MSF code");
 		  break;
 		}
 	      default:
 		lsn = CDIO_INVALID_LSN;
-		cdio_warn("unknown cdte_format %d", cdte_format);
+		cdio_log(log_level,
+			 "unknown cdte_format %d", cdte_format);
 	      }
 	      
 	      sec_count = UINT32_FROM_BE (_entries[idx + 1].lsn);
@@ -368,24 +370,25 @@ parse_nrg (_img_private_t *p_env, const char *psz_nrg_name)
       case DAOX_ID: /* "DAOX" */ 
       case DAOI_ID: /* "DAOI" */
 	{
+	  _daox_t *_xentries = NULL;
+	  _daoi_t *_ientries = NULL;
+	  _dao_array_common_t *_dao_array_common = NULL;
+	  _dao_common_t *_dao_common = (void *) chunk->data;
+	  int disc_mode = _dao_common->unknown[1];
 	  track_format_t track_format;
-	  int disc_mode;
+	  int i;
 
 	  /* We include an extra 0 byte so these can be used as C strings.*/
-	  p_env->psz_mcn    = calloc(1, CDIO_MCN_SIZE+1);
+	  p_env->psz_mcn = calloc(1, CDIO_MCN_SIZE+1);
+	  memcpy(p_env->psz_mcn, &(_dao_common->psz_mcn), CDIO_MCN_SIZE);
+	  p_env->psz_mcn[CDIO_MCN_SIZE] = '\0';
 
 	  if (DAOX_ID == opcode) {
-	    _daox_array_t *_entries = (void *) chunk->data;
-	    disc_mode    = _entries->_unknown[1];
-	    p_env->dtyp  = _entries->_unknown[19];
-	    memcpy(p_env->psz_mcn, &(_entries->psz_mcn), CDIO_MCN_SIZE);
-	    p_env->psz_mcn[CDIO_MCN_SIZE] = '\0';
+	    _xentries = (void *) chunk->data;
+	    p_env->dtyp = _xentries->track_info[0].common.unknown[2];
 	  } else {
-	    _daoi_array_t *_entries = (void *) chunk->data;
-	    disc_mode    = _entries->_unknown[1];
-	    p_env->dtyp  = _entries->_unknown[19];
-	    memcpy(p_env->psz_mcn, &(_entries->psz_mcn), CDIO_MCN_SIZE);
-	    p_env->psz_mcn[CDIO_MCN_SIZE] = '\0';
+	    _ientries = (void *) chunk->data;
+	    p_env->dtyp = _ientries->track_info[0].common.unknown[2];
 	  }
 
 	  p_env->is_dao = true;
@@ -427,7 +430,6 @@ parse_nrg (_img_private_t *p_env, const char *psz_nrg_name)
 	    track_format = TRACK_FORMAT_AUDIO;
 	  }
 	  if (0 == disc_mode) {
-	    int i;
 	    for (i=0; i<p_env->gen.i_tracks; i++) {
 	      cdtext_init (&(p_env->gen.cdtext_track[i]));
 	      p_env->tocent[i].track_format= track_format;
@@ -443,7 +445,6 @@ parse_nrg (_img_private_t *p_env, const char *psz_nrg_name)
 	      }
 	    }
 	  } else if (2 == disc_mode) {
-	    int i;
 	    for (i=0; i<p_env->gen.i_tracks; i++) {
 	      cdtext_init (&(p_env->gen.cdtext_track[i]));
 	      p_env->tocent[i].track_green = true;
@@ -470,6 +471,33 @@ parse_nrg (_img_private_t *p_env, const char *psz_nrg_name)
 		      "Don't know if mode 1, mode 2 or mixed: %x\n", 
 		      disc_mode);
 	  }
+
+	  for (i=0; i<p_env->gen.i_tracks; i++) {
+
+	    if (DAOX_ID == opcode) {
+	      _dao_array_common = &_xentries->track_info[i].common;
+	    } else {
+	      _dao_array_common = &_ientries->track_info[i].common;
+	    }
+	    p_env->tocent[i].isrc = calloc(1, CDIO_ISRC_SIZE+1);
+	    memcpy(p_env->tocent[i].isrc, _dao_array_common->psz_isrc, CDIO_ISRC_SIZE);
+	    p_env->tocent[i].isrc[CDIO_ISRC_SIZE] = '\0';
+	    if (p_env->tocent[i].isrc[0]) {
+	       cdio_info("nrg isrc has value \"%s\"", p_env->tocent[i].isrc);
+	    }
+
+	    if (!p_env->tocent[i].datasize) {
+	      continue;
+	    }
+	    if (DAOX_ID == opcode) {
+	       p_env->tocent[i].pregap = (uint64_from_be
+		(_xentries->track_info[i].index0)) / (p_env->tocent[i].datasize);
+	    } else {
+	       p_env->tocent[i].pregap = (uint32_from_be
+		(_ientries->track_info[i].index0)) / (p_env->tocent[i].datasize);
+	    }
+	  }
+
 	  break;
 	}
       case NERO_ID: 
@@ -714,10 +742,11 @@ parse_nrg (_img_private_t *p_env, const char *psz_nrg_name)
 	break;
 	
       case CDTX_ID: { /* "CD TEXT" */
-	
-	cdio_log (log_level,
-		  "Don't know how to handle CD TEXT yet" );
-	break;
+        uint8_t *wdata = (uint8_t *) chunk->data;
+        int len = UINT32_FROM_BE (chunk->len);
+        cdio_assert (len % sizeof (CDText_data_t) == 0);
+        cdtext_data_init (&p_env->gen, p_env->gen.i_first_track, &wdata[-4], len, set_cdtext_field_generic);
+        break;
       }
 
       default:
@@ -773,7 +802,7 @@ _init_nrg (_img_private_t *p_env)
 
   cdtext_init (&(p_env->gen.cdtext));
 
-  if ( !parse_nrg (p_env, p_env->gen.source_name) ) {
+  if ( !parse_nrg (p_env, p_env->gen.source_name, CDIO_LOG_WARN) ) {
     cdio_warn ("image file %s is not a Nero image", 
 	       p_env->gen.source_name);
     return false;
@@ -802,6 +831,7 @@ _lseek_nrg (void *p_user_data, off_t offset, int whence)
 
   unsigned int i;
 
+  p_env->pos.lba = 0;
   for (i=0; i<p_env->gen.i_tracks; i++) {
     track_info_t  *this_track=&(p_env->tocent[i]);
     p_env->pos.index = i;
@@ -864,7 +894,6 @@ _read_audio_sectors_nrg (void *p_user_data, void *data, lsn_t lsn,
 			  unsigned int nblocks)
 {
   _img_private_t *p_env = p_user_data;
-
   CdioListNode_t *node;
 
   if (lsn >= p_env->size)
@@ -874,6 +903,20 @@ _read_audio_sectors_nrg (void *p_user_data, void *data, lsn_t lsn,
       return -1;
     }
 
+  if (p_env->is_dao) {
+    int ret;
+
+    ret = cdio_stream_seek (p_env->gen.data_source, 
+              (lsn + CDIO_PREGAP_SECTORS) * CDIO_CD_FRAMESIZE_RAW, SEEK_SET);
+    if (ret!=0) return ret;
+
+    ret = cdio_stream_read (p_env->gen.data_source, data, 
+              CDIO_CD_FRAMESIZE_RAW, nblocks);
+
+    /* ret is number of bytes if okay, but we need to return 0 okay. */
+    return ret == 0;
+  }
+
   _CDIO_LIST_FOREACH (node, p_env->mapping) {
     _mapping_t *_map = _cdio_list_node_data (node);
     
@@ -1110,9 +1153,15 @@ cdio_get_default_device_nrg(void)
 static bool
 get_hwinfo_nrg ( const CdIo *p_cdio, /*out*/ cdio_hwinfo_t *hw_info)
 {
-  strcpy(hw_info->psz_vendor, "libcdio");
-  strcpy(hw_info->psz_model, "Nero");
-  strcpy(hw_info->psz_revision, CDIO_VERSION);
+  strncpy(hw_info->psz_vendor, "libcdio",
+	 sizeof(hw_info->psz_vendor)-1);
+  hw_info->psz_vendor[sizeof(hw_info->psz_vendor)-1] = '\0';
+  strncpy(hw_info->psz_model, "Nero",
+	  sizeof(hw_info->psz_model)-1);
+  hw_info->psz_model[sizeof(hw_info->psz_model)-1] = '\0';
+  strncpy(hw_info->psz_revision, CDIO_VERSION, 
+	  sizeof(hw_info->psz_revision)-1);
+  hw_info->psz_revision[sizeof(hw_info->psz_revision)-1] = '\0';
   return true;
   
 }
@@ -1165,29 +1214,34 @@ _get_track_green_nrg(void *p_user_data, track_t track_num)
 
 /*! 
   Check that a NRG file is valid. 
-
-*/
-/* Later we'll probably do better. For now though, this gets us 
-   started for now.
 */
 bool
 cdio_is_nrg(const char *psz_nrg) 
 {
-  unsigned int i;
+  _img_private_t env;
+  bool is_nrg = false;
   
   if (psz_nrg == NULL) return false;
 
-  i=strlen(psz_nrg)-strlen("nrg");
-  
-  if (i>0) {
-    if (psz_nrg[i]=='n' && psz_nrg[i+1]=='r' && psz_nrg[i+2]=='g') {
-      return true;
-    } 
-    else if (psz_nrg[i]=='N' && psz_nrg[i+1]=='R' && psz_nrg[i+2]=='G') {
-      return true;
-    }
+  memset(&env, 0, sizeof(env));
+  if (!(env.gen.data_source = cdio_stdio_new (psz_nrg))) {
+    cdio_warn ("can't open nrg image file %s for reading", psz_nrg);
+    return false;
   }
-  return false;
+
+  if (parse_nrg(&env, psz_nrg, CDIO_LOG_INFO)) {
+    is_nrg = true;
+#ifdef ALSO_TEST_NAME
+    size_t psz_len;
+    psz_len = strlen(psz_nrg);
+    /* At least 4 characters needed for .nrg extension */
+    if ( psz_len < 4 ) return false; 
+    
+    is_nrg = strncasecmp( psz_nrg+(psz_len-3), "nrg", 3 ) == 0;
+#endif
+  }
+  cdio_stdio_destroy(env.gen.data_source);
+  return is_nrg;
 }
 
 /*!
@@ -1229,13 +1283,15 @@ cdio_open_nrg (const char *psz_source)
   _funcs.get_media_changed     = get_media_changed_image;
   _funcs.get_mcn               = _get_mcn_image;
   _funcs.get_num_tracks        = _get_num_tracks_image;
-  _funcs.get_track_channels    = get_track_channels_generic,
-  _funcs.get_track_copy_permit = get_track_copy_permit_image,
+  _funcs.get_track_channels    = get_track_channels_generic;
+  _funcs.get_track_copy_permit = get_track_copy_permit_image;
   _funcs.get_track_format      = get_track_format_nrg;
   _funcs.get_track_green       = _get_track_green_nrg;
   _funcs.get_track_lba         = NULL; /* Will use generic routine via msf */
   _funcs.get_track_msf         = _get_track_msf_image;
-  _funcs.get_track_preemphasis = get_track_preemphasis_generic,
+  _funcs.get_track_preemphasis = get_track_preemphasis_generic;
+  _funcs.get_track_pregap_lba  = get_track_pregap_lba_image;
+  _funcs.get_track_isrc        = get_track_isrc_image;
   _funcs.lseek                 = _lseek_nrg;
   _funcs.read                  = _read_nrg;
   _funcs.read_audio_sectors    = _read_audio_sectors_nrg;
