@@ -1,21 +1,20 @@
 /*
-    $Id: image_common.c,v 1.7 2005/01/23 05:31:03 rocky Exp $
+  $Id: image_common.c,v 1.15 2008/04/22 15:29:12 karl Exp $
 
-    Copyright (C) 2004, 2005 Rocky Bernstein <rocky@panix.com>
+  Copyright (C) 2004, 2005, 2008 Rocky Bernstein <rocky@gnu.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /*! Common image routines. 
@@ -41,7 +40,7 @@
 
 /*!
   Eject media -- there's nothing to do here except free resources.
-  We always return -2.
+  We always return DRIVER_OP_UNSUPPORTED.
  */
 driver_return_code_t
 _eject_media_image(void *p_user_data)
@@ -146,6 +145,20 @@ _get_first_track_num_image(void *p_user_data)
   return p_env->gen.i_first_track;
 }
 
+/*! 
+  Find out if media has changed since the last call.
+  @param p_user_data the CD object to be acted upon.
+  @return 1 if media has changed since last call, 0 if not. Error
+  return codes are the same as driver_return_code_t
+  There is no such thing as changing a media image so we will
+  always return 0 - no change.
+ */
+int
+get_media_changed_image(const void *p_user_data)
+{
+  return 0;
+}
+
 /*!
   Return the media catalog number (MCN) from the CD or NULL if there
   is none or we don't have the ability to get it.
@@ -232,6 +245,97 @@ get_track_preemphasis_image(const void *p_user_data, track_t i_track)
 	   & PRE_EMPHASIS ) ? CDIO_TRACK_FLAG_TRUE : CDIO_TRACK_FLAG_FALSE;
 }
 
+/*! Return the starting LBA for the pregap for track number i_track.
+  Track numbers start at 1.
+  CDIO_INVALID_LBA is returned on error.
+*/
+lba_t
+get_track_pregap_lba_image(const void *p_user_data, track_t i_track)
+{
+  const _img_private_t *p_env = p_user_data;
+  lba_t pregap, start_lba;
+
+  pregap    = p_env->tocent[i_track-p_env->gen.i_first_track].pregap;
+  start_lba = p_env->tocent[i_track-p_env->gen.i_first_track].start_lba;
+
+  /* avoid initializing pregap to CDIO_INVALID_LBA by letting calloc
+     do the work.  also, nero files have the pregap set equal
+     to the start of the track when there is no pregap
+  */
+  if (!pregap || pregap == start_lba) {
+    pregap = CDIO_INVALID_LBA;
+  }
+
+  return pregap;
+}
+
+/*!
+  Return the International Standard Recording Code (ISRC) for track number
+  i_track in p_cdio.  Track numbers start at 1.
+
+  Note: string is malloc'd so caller has to free() the returned
+  string when done with it.
+*/
+char *
+get_track_isrc_image(const void *p_user_data, track_t i_track)
+{
+  const _img_private_t *p_env = p_user_data;
+  char *isrc = p_env->tocent[i_track-p_env->gen.i_first_track].isrc;
+
+  if (isrc && isrc[0]) {
+    return strdup(isrc);
+  } else {
+    return NULL;
+  }
+}
+
+/*!
+  Read a data sector
+  
+  @param p_cdio object to read from
+
+  @param p_buf place to read data into.  The caller should make sure
+  this location can store at least ISO_BLOCKSIZE, M2RAW_SECTOR_SIZE,
+  or M2F2_SECTOR_SIZE depending on the kind of sector getting read. If
+  you don't know whether you have a Mode 1/2, Form 1/ Form 2/Formless
+  sector best to reserve space for the maximum, M2RAW_SECTOR_SIZE.
+
+  @param i_lsn sector to read
+
+  @param i_blocksize size of block. Should be either ISO_BLOCKSIZE
+  M2RAW_SECTOR_SIZE, or M2F2_SECTOR_SIZE. See comment above under
+  p_buf.
+  */
+driver_return_code_t 
+read_data_sectors_image ( void *p_user_data, void *p_buf, 
+			  lsn_t i_lsn,  uint16_t i_blocksize,
+			  uint32_t i_blocks )
+{
+  const _img_private_t *p_env = p_user_data;
+
+  if (!p_env || !p_env->gen.cdio) return DRIVER_OP_UNINIT;
+  
+  {
+    CdIo_t *p_cdio                = p_env->gen.cdio;
+    track_t i_track               = cdio_get_track(p_cdio, i_lsn);
+    track_format_t e_track_format = cdio_get_track_format(p_cdio, i_track);
+
+    switch(e_track_format) {
+    case TRACK_FORMAT_PSX:
+    case TRACK_FORMAT_AUDIO:
+    case TRACK_FORMAT_ERROR:
+      return DRIVER_OP_ERROR;
+    case TRACK_FORMAT_DATA:
+      return cdio_read_mode1_sectors (p_cdio, p_buf, i_lsn, false, i_blocks);
+    case TRACK_FORMAT_CDI:
+    case TRACK_FORMAT_XA:
+      return cdio_read_mode2_sectors (p_cdio, p_buf, i_lsn, false, i_blocks);
+    }
+  }
+  return DRIVER_OP_ERROR;
+}
+
+
 /*!
   Set the arg "key" with "value" in the source device.
   Currently "source" to set the source device in I/O operations 
