@@ -1,22 +1,21 @@
 /*
-    $Id: track.c,v 1.4 2005/02/06 04:20:25 rocky Exp $
+  $Id: track.c,v 1.7 2008/04/22 15:29:12 karl Exp $
 
-    Copyright (C) 2003, 2004, 2005 Rocky Bernstein <rocky@panix.com>
-    Copyright (C) 2001 Herbert Valerio Riedel <hvr@gnu.org>
+  Copyright (C) 2003, 2004, 2005, 2008 Rocky Bernstein <rocky@gnu.org>
+  Copyright (C) 2001 Herbert Valerio Riedel <hvr@gnu.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 /*! Track-related routines. */
 
@@ -229,7 +228,7 @@ cdio_get_track_lba(const CdIo_t *p_cdio, track_t i_track)
   i_track in cdio.  Tracks numbers start at 1.
   The "leadout" track is specified either by
   using i_track LEADOUT_TRACK or the total tracks+1.
-  CDIO_INVALID_LBA is returned on error.
+  CDIO_INVALID_LSN is returned on error.
 */
 lsn_t
 cdio_get_track_lsn(const CdIo_t *p_cdio, track_t i_track)
@@ -246,6 +245,53 @@ cdio_get_track_lsn(const CdIo_t *p_cdio, track_t i_track)
   }
 }
 
+/*!
+  Return the International Standard Recording Code (ISRC) for track number
+  i_track in p_cdio.  Track numbers start at 1.
+
+  Note: string is malloc'd so caller has to free() the returned
+  string when done with it.
+*/
+char *
+cdio_get_track_isrc (const CdIo_t *p_cdio, track_t i_track)
+{
+  if (p_cdio == NULL) return NULL;
+
+  if (p_cdio->op.get_track_isrc) {
+    return p_cdio->op.get_track_isrc (p_cdio->env, i_track);
+  } else {
+    return NULL;
+  }
+}
+
+/*!  
+  Return the starting LBA for the pregap for track number
+  i_track in cdio.  Track numbers start at 1.
+  CDIO_INVALID_LBA is returned on error.
+*/
+lba_t
+cdio_get_track_pregap_lba(const CdIo_t *p_cdio, track_t i_track)
+{
+  if (p_cdio == NULL) return CDIO_INVALID_LBA;
+
+  if (p_cdio->op.get_track_pregap_lba) {
+    return p_cdio->op.get_track_pregap_lba (p_cdio->env, i_track);
+  } else {
+    return CDIO_INVALID_LBA;
+  }
+}
+
+/*!  
+  Return the starting LSN for the pregap for track number
+  i_track in cdio.  Track numbers start at 1.
+  CDIO_INVALID_LSN is returned on error.
+*/
+lsn_t
+cdio_get_track_pregap_lsn(const CdIo_t *p_cdio, track_t i_track)
+{
+  return cdio_lba_to_lsn(cdio_get_track_pregap_lba(p_cdio, i_track));
+}
+
 /*!  
   Return the ending LSN for track number
   i_track in cdio.  CDIO_INVALID_LSN is returned on error.
