@@ -1,23 +1,22 @@
 /*
-  $Id: rock.c,v 1.17 2006/03/17 22:36:31 rocky Exp $
+  $Id: rock.c,v 1.18 2008/04/18 16:02:09 karl Exp $
  
-  Copyright (C) 2005 Rocky Bernstein <rocky@panix.com>
+  Copyright (C) 2005, 2008 Rocky Bernstein <rocky@gnu.org>
   Adapted from GNU/Linux fs/isofs/rock.c (C) 1992, 1993 Eric Youngdale
  
-  This program is free software; you can redistribute it and/or modify
+  This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
+  the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
-  
+
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
 /* Rock Ridge Extensions to iso9660 */
 
 
