@@ -1,21 +1,18 @@
 /*
-  $Id: cd-drive.c,v 1.26 2006/03/17 18:15:10 rocky Exp $
+  $Id: cd-drive.c,v 1.29 2008/06/19 15:44:10 flameeyes Exp $
 
-  Copyright (C) 2004, 2005 Rocky Bernstein <rocky@panix.com>
-  
-  This program is free software; you can redistribute it and/or modify
+  This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
+  the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
-  
+
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /* Program to show drivers installed and capibilites of CD drives. */
@@ -28,13 +25,13 @@
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
-#include <getopt.h>
+#include "getopt.h"
 #include <cdio/cdio.h>
 #include <cdio/mmc.h>
 
 /* Used by `main' to communicate with `parse_opt'. And global options
  */
-struct arguments
+static struct arguments
 {
   uint32_t       debug_level;
   int            version_only;
@@ -61,7 +58,7 @@ parse_options (int argc, char *argv[])
 {
   int opt;
 
-  const char* helpText =
+  static const char helpText[] =
     "Usage: %s [OPTION...]\n" 
     "  -d, --debug=INT                 Set debugging to LEVEL\n"
     "  -i, --cdrom-device[=DEVICE]     show only info about CD-ROM device\n"
@@ -73,12 +70,12 @@ parse_options (int argc, char *argv[])
     "  -?, --help                      Show this help message\n"
     "  --usage                         Display brief usage message\n";
   
-  const char* usageText =
+  static const char usageText[] =
     "Usage: %s [-d|--debug INT] [-i|--cdrom-device DEVICE] [-q|--quiet]\n"
     "        [-V|--version] [-?|--help] [--usage]\n";
 
-  const char* optionsString = "d:i::qV?";
-  struct option optionsTable[] = {
+  static const char optionsString[] = "d:i::qV?";
+  static const struct option optionsTable[] = {
     {"debug", required_argument, NULL, 'd' },
     {"cdrom-device", optional_argument, NULL, 'i' },
     {"quiet", no_argument, NULL, 'q' },
