@@ -1,23 +1,22 @@
 /*
-    $Id: cd-info.c,v 1.152 2008/01/09 04:26:24 rocky Exp $
+  $Id: cd-info.c,v 1.156 2008/09/09 14:44:25 rocky Exp $
 
-    Copyright (C) 2003, 2004, 2005, 2007, 2008 Rocky Bernstein <rocky@gnu.org>
-    Copyright (C) 1996, 1997, 1998  Gerd Knorr <kraxel@bytesex.org>
+  Copyright (C) 2003, 2004, 2005, 2007, 2008 Rocky Bernstein <rocky@gnu.org>
+  Copyright (C) 1996, 1997, 1998  Gerd Knorr <kraxel@bytesex.org>
          and Heiko Eifeldt <heiko@hexco.de>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 /*
   CD Info - prints various information about a CD, and detects the type of 
@@ -25,12 +24,12 @@
 */
 
 #include "util.h"
-#include "cddb.h"
 #include "getopt.h"
 #include <stdarg.h>
 
 #ifdef HAVE_CDDB
 #include <cddb/cddb.h>
+#include "cddb.h"
 #endif
 
 #ifdef HAVE_VCDINFO
@@ -65,13 +64,13 @@
 #define NORMAL ""
 
 #if CDIO_IOCTL_FINISHED
-struct cdrom_multisession  ms;
-struct cdrom_subchnl       sub;
+static struct cdrom_multisession  ms;
+static struct cdrom_subchnl       sub;
 #endif
 
 /* Used by `main' to communicate with `parse_opt'. And global options
  */
-struct opts_s
+static struct opts_s
 {
   int            no_tracks;
   int            no_ioctl;
@@ -119,8 +118,6 @@ enum {
   
 };
 
-char *temp_str;
-
 /* Parse source options. */
 static void
 parse_source(int opt)
@@ -176,7 +173,7 @@ parse_options (int argc, char *argv[])
 {
   int opt; /* used for argument parsing */
 
-  const char* helpText =
+  static const char helpText[] =
     "Usage: %s [OPTION...]\n"
     "  -a, --access-mode=STRING        Set CD access method\n"
     "  -d, --debug=INT                 Set debugging to LEVEL\n"
@@ -244,7 +241,7 @@ parse_options (int argc, char *argv[])
     "  -?, --help                      Show this help message\n"
     "  --usage                         Display brief usage message\n";
   
-  const char* usageText = 
+  static const char usageText[] = 
     "Usage: %s [-a|--access-mode STRING] [-d|--debug INT] [-T|--no-tracks]\n"
     "        [-A|--no-analyze] [--no-cddb] [-P|--cddb-port INT] [-H|--cddb-http]\n"
     "        [--cddb-server=STRING] [--cddb-cache=STRING] [--cddb-email=STRING]\n"
@@ -256,8 +253,8 @@ parse_options (int argc, char *argv[])
     "        [--no-joliet] [--no-rock-ridge] [--no-xa] [-q|--quiet] [-V|--version]\n"
     "        [-?|--help] [--usage]\n";
 
-  const char* optionsString = "a:d:TAP:HvIb::c::N::t::i::C::lqV?";
-  struct option optionsTable[] = {
+  static const char optionsString[] = "a:d:TAP:HvIb::c::N::t::i::C::lqV?";
+  static const struct option optionsTable[] = {
     {"access-mode", required_argument, NULL, 'a'},
     {"debug", required_argument, NULL, 'd' },
     {"no-tracks", no_argument, NULL, 'T' },
@@ -306,6 +303,7 @@ parse_options (int argc, char *argv[])
     case 'd': opts.debug_level = atoi(optarg); break;
     case 'T': opts.no_tracks = 1; break;
     case 'A': opts.no_analysis = 1; break;
+#ifdef HAVE_CDDB
     case 'P': cddb_opts.port = atoi(optarg); break;
     case 'H': cddb_opts.http = 1; break;
     case OP_CDDB_SERVER: cddb_opts.server = strdup(optarg); break;
@@ -313,6 +311,7 @@ parse_options (int argc, char *argv[])
     case OP_CDDB_EMAIL: cddb_opts.email = strdup(optarg); break;
     case OP_CDDB_NOCACHE: cddb_opts.disable_cache = 1; break;
     case OP_CDDB_TIMEOUT: cddb_opts.timeout = atoi(optarg); break;
+#endif
     case 'v': opts.no_vcd = 1; break;
     case 'I': opts.no_ioctl = 1; break;
     case 'b': parse_source(OP_SOURCE_BIN); break;
@@ -630,10 +629,12 @@ print_analysis(int ms_offset, cdio_iso_analysis_t cdio_iso_analysis,
   switch(CDIO_FSTYPE(fs)) {
   case CDIO_FS_AUDIO:
     if (num_audio > 0) {
-      printf("Audio CD, CDDB disc ID is %08x\n", 
-	     cddb_discid(p_cdio, i_tracks));
 #ifdef HAVE_CDDB
-      if (!opts.no_cddb) print_cddb_info(p_cdio, i_tracks, i_first_track);
+      if (!opts.no_cddb) {
+	printf("Audio CD, CDDB disc ID is %08x\n", 
+	       cddb_discid(p_cdio, i_tracks));
+	print_cddb_info(p_cdio, i_tracks, i_first_track);
+      }
 #endif      
       print_cdtext_info(p_cdio, i_tracks, i_first_track);
     }
