@@ -1,26 +1,24 @@
 /*
- * Copyright (C) 2004, 2005, 2006, 2007, 2008 Rocky Bernstein <rocky@gnu.org>
- *           (C) 1998 Monty <xiphmont@mit.edu>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2, or (at your option)
- *   any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- *   02110-1301 USA.
- *
- *
- * See ChangeLog for recent changes.
- *
- */
+  $Id: cd-paranoia.c,v 1.37 2008/06/19 15:44:30 flameeyes Exp $
+
+  Copyright (C) 2004, 2005, 2006, 2007, 2008 Rocky Bernstein <rocky@gnu.org>
+            (C) 1998 Monty <xiphmont@mit.edu>
+
+  This program is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
+
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+  See ChangeLog for recent changes.
+*/
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -284,13 +282,13 @@ static void usage(FILE *f)
   fprintf( f, usage_help);
 }
 
-long callbegin;
-long callend;
-long callscript=0;
+static long callbegin;
+static long callend;
+static long callscript=0;
 
 static int skipped_flag=0;
 static int abort_on_skip=0;
-FILE *logfile = NULL;
+static FILE *logfile = NULL;
 
 #if TRACE_PARANOIA
 static void
@@ -547,9 +545,9 @@ callback(long int inpos, paranoia_cb_mode_t function)
 }
 #endif /* !TRACE_PARANOIA */
 
-const char *optstring = "aBcCd:efg:hi:l:m:n:o:O:pqQrRsS:Tt:VvwWx:XYZz::";
+static const char optstring[] = "aBcCd:efg:hi:l:m:n:o:O:pqQrRsS:Tt:VvwWx:XYZz::";
 
-struct option options [] = {
+static const struct option options [] = {
 	{"abort-on-skip",             no_argument,       NULL, 'X'},
 	{"batch",                     no_argument,       NULL, 'B'},
 	{"disable-extra-paranoia",    no_argument,       NULL, 'Y'},
