@@ -1,25 +1,23 @@
 /*
-    $Id: cdda-player.c,v 1.41 2006/03/17 19:36:54 rocky Exp $
+  $Id: cdda-player.c,v 1.50 2008/06/19 15:44:14 flameeyes Exp $
 
-    Copyright (C) 2005, 2006 Rocky Bernstein <rocky@panix.com>
+  Copyright (C) 2005, 2006, 2008 Rocky Bernstein <rocky@gnu.org>
 
-    Adapted from Gerd Knorr's player.c program  <kraxel@bytesex.org>
-    Copyright (C) 1997, 1998 
+  Adapted from Gerd Knorr's player.c program  <kraxel@bytesex.org>
+  Copyright (C) 1997, 1998 
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301 USA.
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifdef HAVE_CONFIG_H
@@ -73,50 +71,55 @@
 #include "cddb.h"
 #include "getopt.h"
 
-static bool play_track(track_t t1, track_t t2);
+static void action(const char *psz_action);
 static void display_cdinfo(CdIo_t *p_cdio, track_t i_tracks, 
 			   track_t i_first_track);
+static void display_tracks(void);
 static void get_cddb_track_info(track_t i_track);
 static void get_cdtext_track_info(track_t i_track);
 static void get_track_info(track_t i_track);
-static void display_tracks(void);
+static bool play_track(track_t t1, track_t t2);
 
-CdIo_t             *p_cdio;               /* libcdio handle */
-driver_id_t        driver_id = DRIVER_DEVICE;
-int b_sig = false;                                /* set on some signals */
+static CdIo_t             *p_cdio;               /* libcdio handle */
+static driver_id_t        driver_id = DRIVER_DEVICE;
+static int b_sig = false;                        /* set on some signals */
 
 /* cdrom data */
-track_t            i_first_track;
-track_t            i_last_track;
-track_t            i_first_audio_track;
-track_t            i_last_audio_track;
-track_t            i_last_display_track = CDIO_INVALID_TRACK;
-track_t            i_tracks;
-msf_t              toc[CDIO_CDROM_LEADOUT_TRACK+1];
-cdio_subchannel_t  sub;      /* subchannel last time read */
-int                i_data;     /* # of data tracks present ? */
-int                start_track = 0;
-int                stop_track = 0;
-int                one_track = 0;
-int                i_vol_port   = -1; /* If -1 get retrieve volume port.
+static track_t            i_first_track;
+static track_t            i_last_track;
+static track_t            i_first_audio_track;
+static track_t            i_last_audio_track;
+static track_t            i_last_display_track = CDIO_INVALID_TRACK;
+static track_t            i_tracks;
+static msf_t              toc[CDIO_CDROM_LEADOUT_TRACK+1];
+static cdio_subchannel_t  sub;      /* subchannel last time read */
+static int                i_data;     /* # of data tracks present ? */
+static int                start_track = 0;
+static int                stop_track = 0;
+static int                one_track = 0;
+static int                i_vol_port   = 5; /* If 5, retrieve volume port.
 					 Otherwise the port number 0..3
-					 of a working volume port.
+					 of a working volume port and 
+					 4 for no working port.
 				       */
 
-bool               b_cd            = false;
-bool               auto_mode       = false;
-bool               b_verbose       = false;
-bool               debug           = false;
-bool               b_interactive   = true;
-bool               b_prefer_cdtext = true; 
-bool               b_cddb          = false; /* CDDB database present */
-bool               b_db            = false; /* we have a database at all */
-bool               b_record        = false; /* we have a record for
-					the inserted CD */
-bool               b_all_tracks = false; /* True if we display all tracks*/
+/* settings which can be set from the command or interactively. */
+static bool               b_cd            = false;
+static bool               auto_mode       = false;
+static bool               b_verbose       = false;
+static bool               debug           = false;
+static bool               b_interactive   = true;
+static bool               b_prefer_cdtext = true; 
+static bool               b_cddb          = false; /* CDDB database present */
+static bool               b_db            = false; /* we have a database at all */
+static bool               b_record        = false; /* we have a record for
+static 					       the inserted CD */
+static bool               b_all_tracks = false; /* True if we display all tracks*/
+static int8_t             i_volume_level = -1;   /* Valid range is 0..100 */
 
-char *psz_device=NULL;
-char *psz_program;
+
+static char *psz_device=NULL;
+static char *psz_program;
 
 /* Info about songs and titles. The 0 entry will contain the disc info.
  */
@@ -129,28 +132,30 @@ typedef struct
   bool b_cdtext;  /* true if from CD-Text, false if from CDDB */
 } cd_track_info_rec_t;
 
-cd_track_info_rec_t cd_info[CDIO_CD_MAX_TRACKS+2];
+static cd_track_info_rec_t cd_info[CDIO_CD_MAX_TRACKS+2];
 
-char title[80];
-char artist[80];
-char genre[40];
-char category[40];
-char year[5];
+static char title[80];
+static char artist[80];
+static char genre[40];
+static char category[40];
+static char year[5];
 
-bool b_cdtext_title;     /* true if from CD-Text, false if from CDDB */
-bool b_cdtext_artist;    /* true if from CD-Text, false if from CDDB */
-bool b_cdtext_genre;     /* true if from CD-Text, false if from CDDB */
-bool b_cdtext_category;  /* true if from CD-Text, false if from CDDB */
-bool b_cdtext_year;  /* true if from CD-Text, false if from CDDB */
+static bool b_cdtext_title;     /* true if from CD-Text, false if from CDDB */
+static bool b_cdtext_artist;    /* true if from CD-Text, false if from CDDB */
+static bool b_cdtext_genre;     /* true if from CD-Text, false if from CDDB */
+static bool b_cdtext_category;  /* true if from CD-Text, false if from CDDB */
+static bool b_cdtext_year;  /* true if from CD-Text, false if from CDDB */
+
+static cdio_audio_volume_t audio_volume;
 
 #ifdef HAVE_CDDB
-cddb_conn_t *p_conn = NULL;
-cddb_disc_t *p_cddb_disc = NULL;
-int i_cddb_matches = 0;
+static cddb_conn_t *p_conn = NULL;
+static cddb_disc_t *p_cddb_disc = NULL;
+static int i_cddb_matches = 0;
 #endif
 
 #define MAX_KEY_STR 50
-const char key_bindings[][MAX_KEY_STR] = {
+static const char key_bindings[][MAX_KEY_STR] = {
   "    right     play / next track",
   "    left      previous track",
   "    up/down   10 sec forward / back",
@@ -167,9 +172,11 @@ const char key_bindings[][MAX_KEY_STR] = {
   "    q, ^C     quit",
   "    x         quit and continue playing",
   "    a         toggle auto-mode",
+  "    -         decrease volume level",
+  "    +         increase volume level",
 };
 
-const unsigned int i_key_bindings = sizeof(key_bindings) / MAX_KEY_STR;
+static const unsigned int i_key_bindings = sizeof(key_bindings) / MAX_KEY_STR;
 
 /* ---------------------------------------------------------------------- */
 /* tty stuff                                                              */
@@ -188,11 +195,19 @@ typedef enum {
   LINE_TRACK_ARTIST = 10,
   LINE_TRACK_NEXT   = 11,
 
-  LINE_ACTION       = 24,
-  LINE_LAST         = 25
 } track_line_t;
 
-/*! Curses window initialization. */
+static unsigned int  LINE_ACTION = 25;
+static unsigned int  COLS_LAST;
+static char psz_action_line[300] = "";
+
+static int rounded_div(unsigned int i_a, unsigned int i_b) 
+{
+  const unsigned int i_b_half=i_b/2;
+  return ((i_a)+i_b_half)/i_b;
+}
+
+/** Curses window initialization. */
 static void
 tty_raw()
 {
@@ -200,14 +215,17 @@ tty_raw()
   
   initscr();
   cbreak();
+  clear();
   noecho();
 #ifdef HAVE_KEYPAD
   keypad(stdscr,1);
 #endif
+  getmaxyx(stdscr, LINE_ACTION, COLS_LAST);
+  LINE_ACTION--;
   refresh();
 }
 
-/*! Curses window finalization. */
+/** Curses window finalization. */
 static void
 tty_restore()
 {
@@ -215,6 +233,15 @@ tty_restore()
   endwin();
 }
 
+/* Called when window is resized. */
+static void 
+sigwinch()
+{
+  tty_restore();
+  tty_raw();
+  action(NULL);
+}
+
 /* Signal handler - Ctrl-C and others. */
 static void
 ctrlc(int signal)
@@ -238,6 +265,7 @@ select_wait(int sec)
 
 /* ---------------------------------------------------------------------- */
 
+/* Display the action line. */
 static void 
 action(const char *psz_action)
 {
@@ -247,15 +275,20 @@ action(const char *psz_action)
     return;
   }
   
-  if (psz_action && strlen(psz_action))
-    mvprintw(LINE_ACTION, 0, (char *) "action : %s\n", psz_action);
+  if (!psz_action) 
+    psz_action = psz_action_line;
+  else if (psz_action && strlen(psz_action))
+    snprintf(psz_action_line, sizeof(psz_action_line), "action : %s", 
+	     psz_action);
   else
-    mvprintw(LINE_ACTION, 0, (char *) "");
+    snprintf(psz_action_line, sizeof(psz_action_line), "%s", "" );
+  mvprintw(LINE_ACTION, 0, psz_action_line);
   clrtoeol();
   refresh();
 }
 
 
+/* Display an error message.. */
 static void 
 xperror(const char *psz_msg)
 {
@@ -271,11 +304,13 @@ xperror(const char *psz_msg)
   
   if (b_verbose) {
     sprintf(line,"%s: %s", psz_msg, strerror(errno));
+    attron(A_STANDOUT);
     mvprintw(LINE_ACTION, 0, (char *) "error  : %s", line);
+    attroff(A_STANDOUT);
     clrtoeol();
     refresh();
     select_wait(3);
-    action(NULL);
+    action("");
   }
 }
 
@@ -283,7 +318,9 @@ static void
 finish(const char *psz_msg, int rc)
 {
   if (b_interactive) {
-    mvprintw(LINE_LAST, 0, (char *) "%s, exiting...\n", psz_msg);
+    attron(A_STANDOUT);
+    mvprintw(LINE_ACTION, 0, (char *) "%s, exiting...\n", psz_msg);
+    attroff(A_STANDOUT);
     clrtoeol();
     refresh();
   }
@@ -300,7 +337,65 @@ finish(const char *psz_msg, int rc)
 
 /* ---------------------------------------------------------------------- */
 
-/*! Stop playing audio CD */
+/* Set all audio channels to level. level is assumed to be in the range
+   0..100.
+*/
+static bool
+set_volume_level(CdIo_t *p_cdio, uint8_t i_level) 
+{
+  const unsigned int i_new_level= rounded_div(i_level*256, 100);
+  unsigned int i;
+  driver_return_code_t rc;
+  for (i=0; i<=3; i++) {
+    audio_volume.level[i] = i_new_level;
+  }
+  
+  rc = cdio_audio_set_volume(p_cdio, &audio_volume);
+  if ( DRIVER_OP_SUCCESS != rc ) {
+    /* If we can't do a get volume, audio_volume.level is used as
+       a second-best guess. But if this set failed restore it to 
+       an invalid value so we don't get confused and think that this
+       was set. */
+    for (i=0; i<=3; i++) {
+      audio_volume.level[i] = 0;
+    }
+  } else {
+    /* Set i_vol_port so volume levels set above will get used. */
+    i_vol_port=0;
+  }
+  return rc;
+  
+}
+
+/* Add 1 to volume level. If we are at the max or min value wrap
+   around. If volume level is undefined, then this means we
+   could not get the current value and we'll' set it to 50 the midway
+   point.
+   Return status of setting the volume level.
+*/
+static bool
+decrease_volume_level(CdIo_t *p_cdio)
+{
+  if (i_volume_level == -1) i_volume_level = 50;
+  if (i_volume_level == 0)  i_volume_level = 100;
+  return set_volume_level(p_cdio, --i_volume_level);
+}
+
+/* Subtract 1 to volume level. If we are at the max or min value wrap
+   around. If volume level is undefined, then this means we
+   could not get the current value and we'll' set it to 50 the midway
+   point.
+   Return status of setting the volume level.
+*/
+static bool
+increase_volume_level(CdIo_t *p_cdio)
+{
+  if (i_volume_level == -1) i_volume_level = 50;
+  if (i_volume_level == 100) i_volume_level = -1;
+  return set_volume_level(p_cdio, ++i_volume_level);
+}
+
+/** Stop playing audio CD */
 static bool
 cd_stop(CdIo_t *p_cdio)
 {
@@ -316,7 +411,7 @@ cd_stop(CdIo_t *p_cdio)
   return b_ok;
 }
 
-/*! Eject CD */
+/** Eject CD */
 static bool
 cd_eject(void)
 {
@@ -334,7 +429,7 @@ cd_eject(void)
   return b_ok;
 }
 
-/*! Close CD tray */
+/** Close CD tray */
 static bool
 cd_close(const char *psz_device)
 {
@@ -348,7 +443,7 @@ cd_close(const char *psz_device)
   return b_ok;
 }
 
-/*! Pause playing audio CD */
+/** Pause playing audio CD */
 static bool
 cd_pause(CdIo_t *p_cdio)
 {
@@ -361,7 +456,7 @@ cd_pause(CdIo_t *p_cdio)
   return b_ok;
 }
 
-/*! Get status/track/position info of an audio CD */
+/** Get status/track/position info of an audio CD */
 static bool
 read_subchannel(CdIo_t *p_cdio)
 {
@@ -379,7 +474,7 @@ read_subchannel(CdIo_t *p_cdio)
 }
 
 #ifdef HAVE_CDDB
-/*! This routine is called by vcd routines on error. 
+/** This routine is called by vcd routines on error. 
    Setup is done by init_input_plugin.
 */
 static void 
@@ -454,7 +549,7 @@ get_disc_info(CdIo_t *p_cdio)
   }
 }
 
-/*! Read CD TOC  and set CD information. */
+/** Read CD TOC and set CD information. */
 static void
 read_toc(CdIo_t *p_cdio)
 {
@@ -472,15 +567,9 @@ read_toc(CdIo_t *p_cdio)
   i_last_audio_track  = i_last_track;
 
 
-  if ( DRIVER_OP_SUCCESS == cdio_audio_get_volume(p_cdio, NULL) ) {
-    for (i_vol_port=0; i_vol_port<4; i_vol_port++) {
-      if (i_vol_port > 0) break;
-    }
-    if (4 == i_vol_port) 
-      /* Didn't find a non-zero volume level, maybe we've got everthing muted.
-	 Set port to 0 to distinguis from -1 (driver can't get volume).
-      */
-      i_vol_port = 0;
+  cdio_audio_get_volume(p_cdio, &audio_volume);
+  for (i_vol_port=0; i_vol_port<4; i_vol_port++) {
+    if (audio_volume.level[i_vol_port] > 0) break;
   }
   
   if ( CDIO_INVALID_TRACK == i_first_track ||
@@ -529,12 +618,12 @@ read_toc(CdIo_t *p_cdio)
     if (auto_mode && sub.audio_status != CDIO_MMC_READ_SUB_ST_PLAY)
       play_track(1, CDIO_CDROM_LEADOUT_TRACK);
   }
-  action(NULL);
+  action("");
   if (!b_all_tracks)
     display_cdinfo(p_cdio, i_tracks, i_first_track);
 }
 
-/*! Play an audio track. */
+/** Play an audio track. */
 static bool
 play_track(track_t i_start_track, track_t i_end_track)
 {
@@ -550,17 +639,17 @@ play_track(track_t i_start_track, track_t i_end_track)
     return false;
   
   if (debug)
-    fprintf(stderr,"play tracks: %d-%d => ", i_start_track, i_end_track);
+    fprintf(stderr,"play tracks: %d-%d => ", i_start_track, i_end_track-1);
   if (i_start_track < i_first_track)       i_start_track = i_first_track;
   if (i_start_track > i_last_audio_track)  i_start_track = i_last_audio_track;
   if (i_end_track < i_first_track)         i_end_track   = i_first_track;
   if (i_end_track > i_last_audio_track)    i_end_track   = i_last_audio_track;
   i_end_track++;
   if (debug)
-    fprintf(stderr,"%d-%d\n",i_start_track, i_end_track);
+    fprintf(stderr,"%d-%d\n",i_start_track, i_end_track-1);
   
   cd_pause(p_cdio);
-  sprintf(line,"play track %d...", i_start_track);
+  sprintf(line,"play track %d to track %d.", i_start_track, i_end_track-1);
   action(line);
   b_ok = (DRIVER_OP_SUCCESS == cdio_audio_play_msf(p_cdio, 
 						   &(toc[i_start_track]),
@@ -611,7 +700,7 @@ toggle_pause()
   return b_ok;
 }
 
-/*! Update windows with status and possibly track info. This used in 
+/** Update windows with status and possibly track info. This used in 
   interactive playing not batch mode.
  */
 static void
@@ -629,19 +718,16 @@ display_status(bool b_status_only)
     
   } else if (sub.audio_status == CDIO_MMC_READ_SUB_ST_PAUSED ||
 	     sub.audio_status == CDIO_MMC_READ_SUB_ST_PLAY) {
-    cdio_audio_volume_t audio_volume;
-    if (i_vol_port > 0 && 
-	DRIVER_OP_SUCCESS == cdio_audio_get_volume(p_cdio, &audio_volume) ) 
-      {
-	uint8_t i_level = audio_volume.level[i_vol_port];
+    cdio_audio_get_volume(p_cdio, &audio_volume);
+    if (i_vol_port < 4) {
+	i_volume_level = rounded_div(audio_volume.level[i_vol_port]*100, 256);
 	sprintf(line,
 		"track %2d - %02x:%02x of %s (%02x:%02x abs) %s volume: %d",
 		sub.track, sub.rel_addr.m, sub.rel_addr.s, 
 		cd_info[sub.track].length,
 		sub.abs_addr.m, sub.abs_addr.s,
 		mmc_audio_state2str(sub.audio_status),
-		(i_level*100+128) / 256 );
-      
+		i_volume_level);
       } else 
 	sprintf(line,"track %2d - %02x:%02x of %s (%02x:%02x abs) %s",
 		sub.track, sub.rel_addr.m, sub.rel_addr.s,
@@ -651,7 +737,10 @@ display_status(bool b_status_only)
     sprintf(line,"%s", mmc_audio_state2str(sub.audio_status));
     
   }
-  mvprintw(LINE_STATUS, 0, (char *) "status%s: %s",auto_mode ? "*" : " ", line);
+
+  action(NULL);
+  mvprintw(LINE_STATUS, 0, (char *) "status%s: %s",
+	   auto_mode ? "*" : " ", line);
   clrtoeol();
   
   if ( !b_status_only && b_db && i_last_display_track != sub.track && 
@@ -659,7 +748,8 @@ display_status(bool b_status_only)
 	sub.audio_status == CDIO_MMC_READ_SUB_ST_PLAY)  &&
 	b_cd) {
 
-    if (b_all_tracks) display_tracks();
+    if (b_all_tracks) 
+      display_tracks();
     else {
       const cd_track_info_rec_t *p_cd_info = &cd_info[sub.track];
       i_last_display_track = sub.track;
@@ -701,7 +791,7 @@ display_status(bool b_status_only)
     }
   }
 
-  refresh();
+  action(NULL); /* Redisplay action line. */
 
 }
 
@@ -789,7 +879,7 @@ display_cdinfo(CdIo_t *p_cdio, track_t i_tracks, track_t i_first_track)
   
   mvprintw(LINE_CDINFO, 0, (char *) "CD info: %0s", line);
   clrtoeol();
-  refresh();
+  action(NULL);
 }
     
 /* ---------------------------------------------------------------------- */
@@ -831,7 +921,7 @@ usage(char *prog)
 	    "way on a spare console and forget about it...\n"
 	    "\n"
 	    "(c) 1997,98 Gerd Knorr <kraxel@goldbach.in-berlin.de>\n"
-	    "(c) 2005 Rocky Bernstein <rocky@panix.com>\n"
+	    "(c) 2005, 2006 Rocky Bernstein <rocky@panix.com>\n"
 	    , prog, prog);
 }
 
@@ -899,7 +989,12 @@ display_tracks(void)
 	  strcat(line, cd_info[i].artist);
 	}
       }
-      mvprintw(i_line++, 0, line);
+      if (sub.track == i) {
+	attron(A_STANDOUT);
+	mvprintw(i_line++, 0, line);
+	attroff(A_STANDOUT);
+      }	else 
+	mvprintw(i_line++, 0, line);
       clrtoeol();
     }
   }
@@ -1270,7 +1365,6 @@ main(int argc, char *argv[])
   int  c, nostop=0;
   char *h;
   int  i_rc = 0;
-  int  i_volume_level = 0;
   cd_operation_t cd_op = NO_OP; /* operation to do in non-interactive mode */
   
   
@@ -1298,11 +1392,13 @@ main(int argc, char *argv[])
     case 'a':
       auto_mode = 1;
       break;
+
     case 'L':
-      if (NULL != (h = strchr(optarg,'-'))) {
-	i_volume_level = atoi(optarg);
-	cd_op = SET_VOLUME;
-      }
+      i_volume_level = atoi(optarg);
+      cd_op = SET_VOLUME;
+      b_interactive = false;
+      break;
+
     case 't':
       if (NULL != (h = strchr(optarg,'-'))) {
 	*h = 0;
@@ -1389,6 +1485,7 @@ main(int argc, char *argv[])
   signal(SIGQUIT,ctrlc);
   signal(SIGTERM,ctrlc);
   signal(SIGHUP,ctrlc);
+  signal(SIGWINCH, sigwinch);
 
   if (CLOSE_CD != cd_op) {
     /* open device */
@@ -1440,6 +1537,7 @@ main(int argc, char *argv[])
 	case PS_LIST_TRACKS:
 	  ps_list_tracks();
 	  break;
+
 	case PLAY_TRACK:
 	  /* play just this one track */
 	  if (b_record) {
@@ -1449,20 +1547,17 @@ main(int argc, char *argv[])
 	  }
 	  i_rc = play_track(start_track, stop_track) ? 0 : 1;
 	  break;
+
 	case PLAY_CD:
 	  if (b_record)
 	    printf("%s / %s\n", artist, title);
 	  play_track(1,CDIO_CDROM_LEADOUT_TRACK);
 	  break;
+
 	case SET_VOLUME:
-	  {
-	    cdio_audio_volume_t volume;
-	    volume.level[0] = i_volume_level;
-	    i_rc = (DRIVER_OP_SUCCESS == cdio_audio_set_volume(p_cdio, 
-							       &volume))
-	      ? 0 : 1;
-	    break;
-	  }
+	  i_rc = set_volume_level(p_cdio, i_volume_level);
+	  break;
+
 	case LIST_SUBCHANNEL: 
 	  if (read_subchannel(p_cdio)) {
 	    if (sub.audio_status == CDIO_MMC_READ_SUB_ST_PAUSED ||
@@ -1494,7 +1589,15 @@ main(int argc, char *argv[])
       }
     }
   }
-  
+
+  /* Play all tracks *unless* we have a play or paused status
+     already. */
+
+  read_subchannel(p_cdio);
+  if (sub.audio_status != CDIO_MMC_READ_SUB_ST_PAUSED &&
+      sub.audio_status != CDIO_MMC_READ_SUB_ST_PLAY)
+    play_track(1, CDIO_CDROM_LEADOUT_TRACK);
+
   while ( !b_sig ) {
     int key;
     if (!b_cd) read_toc(p_cdio);
@@ -1503,6 +1606,12 @@ main(int argc, char *argv[])
     
     if (1 == select_wait(b_cd ? 1 : 5)) {
       switch (key = getch()) {
+      case '-':
+	decrease_volume_level(p_cdio);
+	break;
+      case '+':
+	increase_volume_level(p_cdio);
+	break;
       case 'A':
       case 'a':
 	auto_mode = !auto_mode;
