@@ -1,21 +1,20 @@
 /*
-  $Id: cddb.c,v 1.6 2007/06/16 20:12:16 rocky Exp $
+  $Id: cddb.c,v 1.8 2008/06/25 08:01:54 rocky Exp $
 
-  Copyright (C) 2005 Rocky Bernstein <rocky@panix.com>
+  Copyright (C) 2005, 2008 Rocky Bernstein <rocky@gnu.org>
   
-  This program is free software; you can redistribute it and/or modify
+  This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
+  the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
-  
+
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifdef HAVE_CONFIG_H
@@ -48,7 +47,7 @@ cddb_dec_digit_sum(int n)
       the total length of the disk, and 
       the number of tracks.
 */
-u_int32_t
+uint32_t
 cddb_discid(CdIo_t *p_cdio, track_t i_tracks)
 {
   int i,t,n=0;
