@@ -1,23 +1,22 @@
 /*
-    $Id: cdinfo-linux.c,v 1.3 2005/03/01 10:53:15 rocky Exp $
+  $Id: cdinfo-linux.c,v 1.4 2008/04/14 17:30:27 karl Exp $
 
-    Copyright (C) 2003 Rocky Bernstein <rocky@panix.com>
-    Copyright (C) 1996,1997,1998  Gerd Knorr <kraxel@bytesex.org>
-         and       Heiko Eifeldt <heiko@hexco.de>
+  Copyright (C) 2003,2008 Rocky Bernstein <rocky@gnu.org>
+  Copyright (C) 1996,1997,1998  Gerd Knorr <kraxel@bytesex.org>
+        and Heiko Eifeldt <heiko@hexco.de>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 /*
   CD Info - prints various information about a CD, and detects the type of 
