@@ -1,22 +1,20 @@
 /*
-    $Id: iso-info.c,v 1.38 2008/01/09 04:26:24 rocky Exp $
+  $Id: iso-info.c,v 1.40 2008/06/19 15:44:16 flameeyes Exp $
 
-    Copyright (C) 2004, 2005, 2006, 2008 Rocky Bernstein <rocky@gnu.org>
+  Copyright (C) 2004, 2005, 2006, 2008 Rocky Bernstein <rocky@gnu.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301 USA.
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 /*
   ISO Info - prints various information about a ISO 9660 image.
@@ -60,7 +58,7 @@
 
 /* Used by `main' to communicate with `parse_opt'. And global options
  */
-struct arguments
+static struct arguments
 {
   uint32_t       debug_level;
   int            version_only;
@@ -84,16 +82,13 @@ enum {
   
 };
 
-char *temp_str;
-
-
 /* Parse a all options. */
 static bool
 parse_options (int argc, char *argv[])
 {
   int opt;
 
-  const char* helpText =
+  static const char helpText[] =
     "Usage: %s [OPTION...]\n"
     "  -d, --debug=INT        Set debugging to LEVEL\n"
     "  -i, --input[=FILE]     Filename to read ISO-9960 image from\n"
@@ -113,13 +108,13 @@ parse_options (int argc, char *argv[])
     "  -?, --help             Show this help message\n"
     "  --usage                Display brief usage message\n";
 
-  const char* usageText =
+  static const char usageText[] =
     "Usage: %s [-d|--debug INT] [-i|--input FILE] [-f] [-l|--iso9660]\n"
     "        [--no-header] [--no-joliet] [--no-rock-ridge] [--no-xa] [-q|--quiet]\n"
     "        [-V|--version] [-?|--help] [--usage]\n";
 
-  const char* optionsString = "d:i::flqV?";
-  struct option optionsTable[] = {
+  static const char optionsString[] = "d:i::flqV?";
+  static const struct option optionsTable[] = {
     {"debug", required_argument, NULL, 'd'},
     {"input", optional_argument, NULL, 'i'},
     {"iso9660", no_argument, NULL, 'l'},
